#!/usr/bin/env python 
# -*- coding:utf-8 -*-

'''
:Name:	YamlFileOperate.py
:Author:	Zheng Yabiao
:Usage:	Yaml file operation
:Data:	2017.5.23
:Version: v1.0
'''

from collections import defaultdict

class YamlWrite:
    """Class of yaml file write out

    :Args:
        input: The yaml file of writing out
    :Returns:
        None
    """
    def __init__(self, file, mode):
        self.file = file
        self.mode = mode
    def yaml_write_dict(self, input_dict, level = 0):
        """Dictionary write out

        :Args:
            * input_dict: The dictionary
            * level (int): The indent level
        :Returns:
            None
        """
        space = int(level) * 4 * " "
        for k in input_dict:
            if not k: continue
            file_handle = open(self.file, self.mode)
            file_handle.write("%s%s:\n"%(space, k))
            file_handle.close()
            if type(input_dict[k]) == type(1) or type(input_dict[k]) == type("1"):
                self.yaml_write_str(input_dict[k], level + 1)
            elif type(input_dict[k]) == type([1, 2]):
                self.yaml_write_list(input_dict[k], level + 1)
            elif type(input_dict[k]) == type({1: 2}) or type(input_dict[k]) == type(defaultdict()):
                self.yaml_write_dict(input_dict[k], level + 1)
    def yaml_write_list(self, input_list, level = 0):
        """List write out

        :Args:
            * input_list: list
            * space: the number of spaces behind the element
        :Returns:
            None
        """
        file_handle = open(self.file, self.mode)
        space = int(level) * 4 * " "
        for i in input_list:
            file_handle.write("%s- %s\n" %(space, i))
    def yaml_write_str(self, input_strg, level = 0):
        """String write out

        :Args:
            * input_strg: string
            * level: the number of spaces behind the string
        :Returns:
            None
        """
        file_handle = open(self.file, self.mode)
        space = int(level) * 4 * " "
        file_handle.write("%s%s\n" %(space, input_strg))



#!/usr/bin/env python3
__author__ = "gj"

from setuptools import setup,find_packages

setup(
	name = "kclib",
	version = "1.0.3",
	author = "gj",
	packages = find_packages(),
	license="GPLv3",
	python_requires = ">=3.6",
	install_requires=["xlrd"]
)



#!/usr/bin/env python 
# -*- coding:utf-8 -*-

'''
:Name:	ParserXLS.py
:Author:	Zheng Yabiao
:Usage:	Parse GEO.xls file and return corresponding information.
:Data:	2017.5.23
:Version: v1.0
'''

import sys
from collections import defaultdict
import xlrd


def open_xls(file,  sheet_name = ""):
    """open xls file;
       return the sheet table
    """
    try:
        data = xlrd.open_workbook(file)
        if sheet_name:
            table = data.sheet_by_name(sheet_name)
            return table
    except IOError:
        print(file + " or the " + sheet_name + " sheet doesn't exist!")

def list_index(list, key, start_pos = 0):
    list = [str(i).strip() for i in list]
    try:
        a = list.index(str(key), start_pos)
        return a
    except:
        if key == "":
            return len(list)
        else:
            print("The key of '" + str(key) + "' doesn't exist after the index of %d" %(start_pos))
            sys.exit(1)

def fetch_row(file, key,  sheet_name = ""):
    """Fetch row information in Excel file

    :Args:
        * file (file): input Excel file
        * key (str): the title word for information fields
        * sheet_index (int): the sheet index in file
        * sheet_name (str): the sheet name in file
    :Returns:
        * row_contents (list): list of row information
    """
    table = open_xls(file, sheet_name)
    key_index = list_index(table.col_values(0), key)
    end_index = list_index(table.col_values(0), "END", key_index + 1)
    row_contents = []
    for line in range(key_index + 1, end_index):
        try:
            if table.row_values(line)[0].startswith("#"):
                continue
        except:
            pass
        if table.row_values(line)[0]:
            row_contents.append(table.row_values(line))
    return row_contents

def fetch_col(file, key,  sheet_name = ""):
    """Fetch row information in Excel file

    :Args:
        * file (file): input Excel file
        * key (str): the title word for information fields
        * sheet_index (int): the sheet index in file
        * sheet_name (str): the sheet name in file
    :Returns:
        * col_contents (list): two-layer list. first is header line, second is information.
    """
    table = open_xls(file, sheet_name)
    key_index = list_index(table.col_values(0), key)
    end_index = list_index(table.col_values(0), "END", key_index + 1)
    col_contents = [[],[]]
    for line in range(key_index + 1, end_index):
        if table.row_values(line)[0].startswith("#"):
            continue
        if table.row_values(line)[0]:
            col_contents[0].append(table.row_values(line)[0])
            col_contents[1].append(table.row_values(line)[1])
    return col_contents
